@@ -612,6 +612,35 @@ echo "✓ Terminal service installed and started successfully"
 echo "✓ WebSocket Terminal Server configured"
 cd /root/whp
 
+# Setup SSH/FTP Log Monitoring System
+echo ""
+echo "======================================"
+echo "Setting up SSH/FTP Log Monitoring..."
+
+# Create necessary directories
+mkdir -p /var/log/proftpd
+mkdir -p /docker/whp/sql
+chmod 755 /var/log/proftpd
+chmod 755 /docker/whp/sql
+
+# Make log monitor cron script executable
+if [ -f "/root/whp/scripts/log_monitor_cron.sh" ]; then
+    chmod +x /root/whp/scripts/log_monitor_cron.sh
+    
+    # Add cron job for log monitoring (runs every 5 minutes)
+    if ! crontab -l 2>/dev/null | grep -q "log_monitor_cron.sh"; then
+        (crontab -l 2>/dev/null; echo "# WHP SSH/FTP Log Monitoring - Check logs every 5 minutes") | crontab -
+        (crontab -l 2>/dev/null; echo "*/5 * * * * /root/whp/scripts/log_monitor_cron.sh >/dev/null 2>&1") | crontab -
+        echo "✓ SSH/FTP log monitoring cron job configured"
+    else
+        echo "✓ SSH/FTP log monitoring cron job already exists"
+    fi
+else
+    echo "⚠ SSH/FTP log monitoring script not found - skipping"
+fi
+
+echo "✓ SSH/FTP Log Monitoring configured"
+
 echo ""
 echo "🎉 Setup completed!"
 echo ""
@@ -639,6 +668,8 @@ echo "10. WordPress security settings include comprehensive options: file editor
 echo "11. WebSocket terminal server provides full terminal access to containers via the web interface"
 echo "12. PostgreSQL database server is running on port 5432 with root credentials stored in /root/.pgpass"
 echo "13. Adminer is available for PostgreSQL management via the WHP interface"
+echo "14. SSH/FTP log monitoring automatically blocks IPs after failed login attempts (configurable via Security Management)"
+echo "15. Log monitoring runs every 5 minutes checking /var/log/auth.log (SSH) and /var/log/proftpd/proftpd.log (FTP)"
 echo ""
 echo "Troubleshooting:"
 echo "- Check logs in /var/log/httpd/ for Apache issues"
@@ -650,6 +681,8 @@ echo "- Check WordPress auto-update logs in /var/log/wordpress-auto-update.log"
 echo "- WordPress management includes WP-CLI integration, security settings, auto-updates, and backup functionality"
 echo "- Check terminal server logs: journalctl -u whp-terminal -f"
 echo "- Verify WebSocket proxy: curl -I http://localhost:8080/terminal-ws"
+echo "- Check SSH/FTP log monitoring: /var/log/whp-log-monitor.log"
+echo "- Manually trigger log check: /root/whp/scripts/log_monitor_cron.sh"
 echo "REBOOT THE SERVER NOW"
 echo ""
 
