@@ -19,6 +19,62 @@ function loadServerSettings() {
 $server_settings = loadServerSettings();
 $server_name = $server_settings['server_name'] ?? 'Web Hosting Panel';
 
+// Check if user is a delegated user and get their permissions
+$is_delegated_user = isset($_SESSION['user_type']) && $_SESSION['user_type'] === 'delegated';
+$delegated_permissions = [];
+$delegated_display_name = '';
+
+if ($is_delegated_user) {
+    // Load delegated user permissions from session
+    $delegated_permissions = $_SESSION['delegated_permissions'] ?? [];
+    $delegated_display_name = $_SESSION['delegated_display_name'] ?? '';
+}
+
+// Function to check if delegated user has permission for a menu item
+function canAccessPage($page, $is_delegated_user, $delegated_permissions) {
+    if (!$is_delegated_user) {
+        return true; // Regular users and root can access all pages
+    }
+    
+    // Map pages to permission requirements
+    $page_permissions = [
+        'domains' => 'can_manage_domains',
+        'sites' => 'can_manage_sites', 
+        'database-management' => 'can_manage_databases',
+        'postgresql-management' => 'can_manage_databases',
+        'email-management' => 'can_manage_email',
+        'backups' => 'can_manage_backups',
+        'wordpress' => 'can_manage_wordpress',
+        'terminal' => 'can_view_terminal',
+        'filemanager' => 'can_manage_files', // For file manager links
+        'phpmyadmin-sso' => 'can_manage_databases',
+        'adminer-sso' => 'can_manage_databases',
+    ];
+    
+    // Always allow dashboard and delegated-users pages
+    if (in_array($page, ['dashboard', 'delegated-users'])) {
+        return true;
+    }
+    
+    // Root-only pages (delegated users never have access)
+    $root_only_pages = [
+        'user-management', 'security-management', 'announcements-management',
+        'update-management', 'docker-management', 'user-resources', 
+        'server-settings', 'cpanel-import'
+    ];
+    
+    if (in_array($page, $root_only_pages)) {
+        return false;
+    }
+    
+    // Check specific permission for page
+    if (isset($page_permissions[$page])) {
+        return !empty($delegated_permissions[$page_permissions[$page]]);
+    }
+    
+    return true; // Default allow for unknown pages
+}
+
 // Whitelist of allowed pages
 $allowed_pages = [
     'dashboard' => 'Dashboard',
@@ -102,7 +158,13 @@ if (!array_key_exists($page, $allowed_pages)) {
                 <!-- User Dropdown -->
                 <div class="navbar-nav ms-auto">
                     <span class="navbar-text text-light me-3">
-                        Welcome, <?php echo htmlspecialchars(AUTH_USER); ?>
+                        Welcome, <?php 
+                        if ($is_delegated_user && !empty($delegated_display_name)) {
+                            echo htmlspecialchars($delegated_display_name);
+                        } else {
+                            echo htmlspecialchars(AUTH_USER);
+                        }
+                        ?>
                     </span>
                     <div class="nav-item dropdown">
                         <a class="nav-link dropdown-toggle" href="#" role="button" data-bs-toggle="dropdown" aria-expanded="false">
@@ -131,42 +193,66 @@ if (!array_key_exists($page, $allowed_pages)) {
                     <a href="index.php?page=dashboard" class="list-group-item list-group-item-action py-3 <?php echo $page === 'dashboard' ? 'active' : ''; ?>">
                         <i class="fa fa-th-large me-3"></i>Dashboard
                     </a>
+                    <?php if (canAccessPage('filemanager', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="./filemanager/" target="_blank" class="list-group-item list-group-item-action py-3">
                         <i class="fa fa-file me-3"></i>File Manager
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('database-management', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=database-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'database-management' ? 'active' : ''; ?>">
                         <i class="fa fa-database me-3"></i>MySQL Management
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('phpmyadmin-sso', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="./phpmyadmin-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
                         <i class="fa fa-database me-3"></i>phpMyAdmin
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('postgresql-management', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=postgresql-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'postgresql-management' ? 'active' : ''; ?>">
                         <i class="fa fa-database me-3"></i>PostgreSQL Management
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('adminer-sso', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="./adminer-sso.php" target="_blank" class="list-group-item list-group-item-action py-3">
                         <i class="fa fa-database me-3"></i>Adminer
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('email-management', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=email-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'email-management' ? 'active' : ''; ?>">
                         <i class="fa fa-envelope me-3"></i>Email Management
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('backups', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=backups" class="list-group-item list-group-item-action py-3 <?php echo $page === 'backups' ? 'active' : ''; ?>">
                         <i class="fa fa-cloud-upload me-3"></i>Backup Management
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('domains', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=domains" class="list-group-item list-group-item-action py-3 <?php echo $page === 'domains' ? 'active' : ''; ?>">
                         <i class="fa fa-globe me-3"></i>Domains
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('sites', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=sites" class="list-group-item list-group-item-action py-3 <?php echo $page === 'sites' ? 'active' : ''; ?>">
                         <i class="fa fa-server me-3"></i>Sites
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('terminal', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=terminal" class="list-group-item list-group-item-action py-3 <?php echo $page === 'terminal' ? 'active' : ''; ?>">
                         <i class="fa fa-terminal me-3"></i>Terminal
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('wordpress', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=wordpress" class="list-group-item list-group-item-action py-3 <?php echo $page === 'wordpress' ? 'active' : ''; ?>">
                         <i class="fa fa-wordpress me-3"></i>WordPress Management
                     </a>
+                    <?php endif; ?>
+                    <?php if (canAccessPage('cpanel-import', $is_delegated_user, $delegated_permissions)): ?>
                     <a href="index.php?page=cpanel-import" class="list-group-item list-group-item-action py-3 <?php echo $page === 'cpanel-import' ? 'active' : ''; ?>">
                         <i class="fa fa-upload me-3"></i>cPanel Import
                     </a>
+                    <?php endif; ?>
                     <?php if (defined('AUTH_USER') && AUTH_USER === 'root'): ?>
                     <a href="index.php?page=user-management" class="list-group-item list-group-item-action py-3 <?php echo $page === 'user-management' ? 'active' : ''; ?>">
                         <i class="fa fa-users me-3"></i>User Management
