@@ -254,9 +254,18 @@ foreach ($security_blocked_ips as $security_block) {
     
     // If not found in service blocks, add it
     if (!$found_in_service) {
+        // Determine the service based on the reason
+        $service = 'whp'; // Default to WHP for security manager blocks
+        if (stripos($security_block['reason'], 'manual') !== false) {
+            $service = 'manual';
+        } elseif (stripos($security_block['reason'], 'failed login') !== false) {
+            $service = 'whp';
+        }
+        
         $service_blocked_ips[] = [
             'ip_address' => $security_block['ip_address'],
             'service_type' => 'security_manager',
+            'service' => $service, // Add the service field
             'blocking_service' => 'security_manager',
             'reason' => $security_block['reason'],
             'block_time' => $security_block['block_time'],
@@ -318,7 +327,8 @@ $access_stats = $PermManager->get_system_access_stats(30);
             </div>
             <div class="card-body text-center">
                 <?php 
-                $total_blocked = $service_stats['ssh']['blocked_ips'] + $service_stats['ftp']['blocked_ips'] + $security_stats['blocked_ips'];
+                // Count unique blocked IPs (each IP only counted once)
+                $total_blocked = count($service_blocked_ips);
                 ?>
                 <h2 class="text-danger"><?php echo $total_blocked; ?></h2>
                 <p class="mb-0">Currently blocked across all services</p>
@@ -767,24 +777,49 @@ if (!empty($service_blocked_ips)): ?>
                             <tr>
                                 <td>
                                     <?php 
-                                    // Show the original service/method that caused the block
-                                    $blocking_service = $blocked['blocking_service'] ?? $blocked['service_type'];
+                                    // Get the service that blocked the IP
+                                    $blocking_service = '';
+                                    $service_display = 'UNKNOWN';
+                                    $badge_class = 'secondary';
+                                    
+                                    // Check the actual service field if available
+                                    if (!empty($blocked['service'])) {
+                                        $blocking_service = $blocked['service'];
+                                    } elseif (!empty($blocked['blocking_service'])) {
+                                        $blocking_service = $blocked['blocking_service'];
+                                    } elseif (!empty($blocked['service_type'])) {
+                                        $blocking_service = $blocked['service_type'];
+                                    }
+                                    
+                                    // Also check the reason for clues
                                     $reason = $blocked['reason'] ?? '';
                                     
-                                    // Determine the block source from the reason or blocking service
-                                    if (stripos($reason, 'manual') !== false || $blocking_service == 'security_manager') {
-                                        $badge_class = 'warning';
-                                        $service_display = 'MANUAL';
-                                    } elseif (stripos($reason, 'whp') !== false || stripos($reason, 'failed login') !== false) {
-                                        $badge_class = 'success';
-                                        $service_display = 'WHP';
-                                    } elseif ($blocking_service == 'ssh') {
+                                    // Determine display based on service or reason
+                                    if ($blocking_service == 'ssh' || stripos($reason, 'ssh') !== false) {
                                         $badge_class = 'primary';
                                         $service_display = 'SSH';
-                                    } elseif ($blocking_service == 'ftp') {
+                                    } elseif ($blocking_service == 'ftp' || stripos($reason, 'ftp') !== false) {
                                         $badge_class = 'info';
                                         $service_display = 'FTP';
-                                    } else {
+                                    } elseif ($blocking_service == 'whp' || stripos($reason, 'whp') !== false || stripos($reason, 'failed login') !== false) {
+                                        $badge_class = 'success';
+                                        $service_display = 'WHP';
+                                    } elseif ($blocking_service == 'haproxy' || stripos($reason, 'haproxy') !== false) {
+                                        $badge_class = 'danger';
+                                        $service_display = 'HAProxy';
+                                    } elseif (stripos($reason, 'manual') !== false) {
+                                        $badge_class = 'warning';
+                                        $service_display = 'MANUAL';
+                                    } elseif ($blocking_service == 'security_manager') {
+                                        // For security_manager, check if it's manual or WHP
+                                        if (stripos($reason, 'manual') !== false) {
+                                            $badge_class = 'warning';
+                                            $service_display = 'MANUAL';
+                                        } else {
+                                            $badge_class = 'success';
+                                            $service_display = 'WHP';
+                                        }
+                                    } elseif (!empty($blocking_service)) {
                                         $badge_class = 'secondary';
                                         $service_display = strtoupper($blocking_service);
                                     }
@@ -809,20 +844,32 @@ if (!empty($service_blocked_ips)): ?>
                                     </small>
                                 </td>
                                 <td>
-                                    <small title="<?php echo date('Y-m-d H:i:s', $blocked['unblock_time']); ?>">
-                                        <?php 
+                                    <?php 
+                                    // Check if this is an indefinite block
+                                    if ($blocked['unblock_time'] == 0 || $blocked['unblock_time'] == 4102444799) {
+                                        // Indefinite block (0 or year 2099)
+                                        echo '<small class="text-danger"><strong>Indefinite</strong></small>';
+                                    } else {
                                         $time_left = $blocked['unblock_time'] - time();
-                                        if ($time_left > 86400) {
+                                        if ($time_left <= 0) {
+                                            echo '<small class="text-success">Expired</small>';
+                                        } elseif ($time_left > 86400) {
+                                            echo '<small title="' . date('Y-m-d H:i:s', $blocked['unblock_time']) . '">';
                                             echo floor($time_left / 86400) . 'd ' . floor(($time_left % 86400) / 3600) . 'h';
+                                            echo '</small>';
                                         } elseif ($time_left > 3600) {
+                                            echo '<small title="' . date('Y-m-d H:i:s', $blocked['unblock_time']) . '">';
                                             echo floor($time_left / 3600) . 'h ' . floor(($time_left % 3600) / 60) . 'm';
+                                            echo '</small>';
                                         } elseif ($time_left > 60) {
+                                            echo '<small title="' . date('Y-m-d H:i:s', $blocked['unblock_time']) . '">';
                                             echo floor($time_left / 60) . 'm';
+                                            echo '</small>';
                                         } else {
-                                            echo 'Soon';
+                                            echo '<small title="' . date('Y-m-d H:i:s', $blocked['unblock_time']) . '">Soon</small>';
                                         }
-                                        ?>
-                                    </small>
+                                    }
+                                    ?>
                                 </td>
                                 <td><span class="badge bg-warning"><?php echo $blocked['failed_attempts']; ?></span></td>
                                 <td class="text-truncate" style="max-width: 200px;" title="<?php echo htmlspecialchars($blocked['reason']); ?>">
@@ -833,7 +880,7 @@ if (!empty($service_blocked_ips)): ?>
                                         <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                                         <input type="hidden" name="action" value="unblock_service_ip">
                                         <input type="hidden" name="ip_address" value="<?php echo htmlspecialchars($blocked['ip_address']); ?>">
-                                        <button type="submit" class="btn btn-warning btn-sm">Unblock All</button>
+                                        <button type="submit" class="btn btn-warning btn-sm">Unblock</button>
                                     </form>
                                 </td>
                             </tr>
